==> generator-bootstrap-less-2.0.4.tgz: package/app/index.js <==
'use strict';
var util = require('util');
var path = require('path');
var yeoman = require('yeoman-generator');


var BootstrapLessGenerator = module.exports = function BootstrapLessGenerator(args, options, config) {
  yeoman.generators.Base.apply(this, arguments);

  // setup the test-framework property, Gruntfile template will need this
  this.testFramework = options['test-framework'] || 'mocha';

  // for hooks to resolve on mocha by default
  if (!options['test-framework']) {
    options['test-framework'] = 'mocha';
  }
  // resolved to mocha by default (could be switched to jasmine for instance)
  this.hookFor('test-framework', { as: 'app' });

  this.indexFile = this.readFileAsString(path.join(this.sourceRoot(), 'index.html'));
  this.mainJsFile = '';

  this.on('end', function () {
    this.installDependencies({ skipInstall: options['skip-install'] });
  });

  this.pkg = JSON.parse(this.readFileAsString(path.join(__dirname, '../package.json')));
};

util.inherits(BootstrapLessGenerator, yeoman.generators.Base);

BootstrapLessGenerator.prototype.askFor = function askFor() {
  var cb = this.async();

  // welcome message
  var welcome =
  '\n     _-----_' +
  '\n    |       |' +
  '\n    |' + '--(o)--'.red + '|   .--------------------------.' +
  '\n   `---------´  |    ' + 'Welcome to Yeoman,'.yellow.bold + '    |' +
  '\n    ' + '( '.yellow + '_' + '´U`'.yellow + '_' + ' )'.yellow + '   |   ' + 'ladies and gentlemen!'.yellow.bold + '  |' +
  '\n    /___A___\\   \'__________________________\'' +
  '\n     |  ~  |'.yellow +
  '\n   __' + '\'.___.\''.yellow + '__' +
  '\n ´   ' + '`  |'.red + '° ' + '´ Y'.red + ' `\n';

  console.log(welcome);

  var prompts = [{
    name: 'fontawesome',
    message: 'Would you like to use FontAwesome?',
    default: 'Y/n',
    warning: 'Yes: Enabling this will be totally awesome!'
  }, {
    name: 'jsBootstrap',
    message: 'Would you like to use Bootstrap Javascript files?',
    default: 'Y/n',
    warning: 'Yes: Enabling this will be totally awesome!'
  }];

  this.prompt(prompts, function (err, props) {
    if (err) {
      return this.emit('error', err);
    }

    this.fontawesome = (/y/i).test(props.fontawesome);
    this.jsBootstrap = (/y/i).test(props.jsBootstrap);

    cb();
  }.bind(this));
};

BootstrapLessGenerator.prototype.gruntfile = function gruntfile() {
  this.template('Gruntfile.js');
};

BootstrapLessGenerator.prototype.packageJSON = function packageJSON() {
  this.template('_package.json', 'package.json');
};

BootstrapLessGenerator.prototype.git = function git() {
  this.copy('gitignore', '.gitignore');
  this.copy('gitattributes', '.gitattributes');
};

BootstrapLessGenerator.prototype.bower = function bower() {
  this.copy('bowerrc', '.bowerrc');
  this.copy('_bower.json', 'bower.json');
};

BootstrapLessGenerator.prototype.jshint = function jshint() {
  this.copy('jshintrc', '.jshintrc');
};

BootstrapLessGenerator.prototype.editorConfig = function editorConfig() {
  this.copy('editorconfig', '.editorconfig');
};

BootstrapLessGenerator.prototype.h5bp = function h5bp() {
  this.copy('favicon.ico', 'app/favicon.ico');
  this.copy('404.html', 'app/404.html');
  this.copy('robots.txt', 'app/robots.txt');
  this.copy('htaccess', 'app/.htaccess');
};

BootstrapLessGenerator.prototype.mainStylesheet = function mainStylesheet() {
  var html = '@import "../bower_components/bootstrap/less/bootstrap.less";\n@import "../bower_components/bootstrap/less/responsive.less"; // Don\'t forget to comment lines 22 to remove the second import call to **mixin.less**\n\n';

  if (this.fontawesome) {
    html = html + '@import "../bower_components/font-awesome/less/font-awesome.less";\n@FontAwesomePath: "../fonts";\n';
  } else {
    html = html + '@iconSpritePath: "../images/glyphicons-halflings.png";\n@iconWhiteSpritePath: "../images/glyphicons-halflings-white.png";\n\n';
  }
  html = html + '.hero-unit {\n  margin: 50px auto 0 auto;\n}';
  this.write('app/styles/main.less', html);
};

BootstrapLessGenerator.prototype.writeIndex = function writeIndex() {
  // prepare default content text
  var defaults = ['HTML5 Boilerplate', 'Twitter Bootstrap'];
  var contentText = [
    '    <div class="container">',
    '      <div class="hero-unit">',
    '        <h1>\'Allo, \'Allo!</h1>',
    '        <p>You now have</p>',
    '        <ul>'
  ];

  this.indexFile = this.appendScripts(this.indexFile, 'scripts/main.js', [
    'bower_components/jquery/jquery.js',
    'scripts/main.js',
    'scripts/hello.js'
  ]);


  if (this.jsBootstrap) {
    // wire Twitter Bootstrap plugins
    this.indexFile = this.appendScripts(this.indexFile, 'scripts/vendor/bootstrap.js', [
      'bower_components/bootstrap/js/bootstrap-affix.js',
      'bower_components/bootstrap/js/bootstrap-alert.js',
      'bower_components/bootstrap/js/bootstrap-dropdown.js',
      'bower_components/bootstrap/js/bootstrap-tooltip.js',
      'bower_components/bootstrap/js/bootstrap-modal.js',
      'bower_components/bootstrap/js/bootstrap-transition.js',
      'bower_components/bootstrap/js/bootstrap-button.js',
      'bower_components/bootstrap/js/bootstrap-popover.js',
      'bower_components/bootstrap/js/bootstrap-typeahead.js',
      'bower_components/bootstrap/js/bootstrap-carousel.js',
      'bower_components/bootstrap/js/bootstrap-scrollspy.js',
      'bower_components/bootstrap/js/bootstrap-collapse.js',
      'bower_components/bootstrap/js/bootstrap-tab.js'
    ]);
  }

  if (this.fontawesome) {
    defaults.push('Font Awesome');
  }

  this.mainJsFile = 'console.log(\'\\\'Allo \\\'Allo!\');';
  this.mainCoffeeFile = 'console.log "\'Allo from CoffeeScript!"';

  // iterate over defaults and create content string
  defaults.forEach(function (el) {
    contentText.push('          <li>' + el  + '</li>');
  });

  contentText = contentText.concat([
    '        </ul>',
    '        <p>installed.</p>',
    '        <h3>Enjoy coding! - Yeoman</h3>',
    '      </div>',
    '    </div>',
    ''
  ]);

  // append the default content
  this.indexFile = this.indexFile.replace('<body>', '<body>\n' + contentText.join('\n'));
};

BootstrapLessGenerator.prototype.app = function app() {
  this.mkdir('app');
  this.mkdir('app/scripts');
  this.mkdir('app/styles');
  this.mkdir('app/images');
  this.write('app/index.html', this.indexFile);
  this.write('app/scripts/hello.coffee', this.mainCoffeeFile);
  this.write('app/scripts/main.js', this.mainJsFile);
};

==> generator-bootstrap-less-3.0.1.tgz: package/app/index.js <==
'use strict';
var util = require('util');
var path = require('path');
var yeoman = require('yeoman-generator');


var BootstrapLessGenerator = module.exports = function BootstrapLessGenerator(args, options, config) {
  yeoman.generators.Base.apply(this, arguments);

  // setup the test-framework property, Gruntfile template will need this
  this.testFramework = options['test-framework'] || 'mocha';

  // for hooks to resolve on mocha by default
  if (!options['test-framework']) {
    options['test-framework'] = 'mocha';
  }
  // resolved to mocha by default (could be switched to jasmine for instance)
  this.hookFor('test-framework', { as: 'app' });

  this.indexFile = this.readFileAsString(path.join(this.sourceRoot(), 'index.html'));
  this.mainJsFile = '';

  this.on('end', function () {
    this.installDependencies({ skipInstall: options['skip-install'] });
  });

  this.pkg = JSON.parse(this.readFileAsString(path.join(__dirname, '../package.json')));
};

util.inherits(BootstrapLessGenerator, yeoman.generators.Base);

BootstrapLessGenerator.prototype.askFor = function askFor() {
  var cb = this.async();

  // welcome message
  console.log(this.yeoman);

  var prompts = [{
    type: 'checkbox',
    name: 'features',
    message: 'What more would you like?',
    choices: [{
      name: 'Bootstrap Javascript files',
      value: 'jsBootstrap',
      checked: true
    }, {
      name: 'Bootstrap-Glyphicons',
      value: 'glyphicons',
      checked: true
    }, {
      name: 'FontAwesome',
      value: 'fontawesome',
      checked: false
    }]
  }];

  this.prompt(prompts, function (answers) {
    var features = answers.features;
    this.jsBootstrap = features.indexOf('jsBootstrap') !== -1;
    this.glyphicons = features.indexOf('glyphicons') !== -1;
    this.fontawesome = features.indexOf('fontawesome') !== -1;

    cb();
  }.bind(this));
};

BootstrapLessGenerator.prototype.gruntfile = function gruntfile() {
  this.template('Gruntfile.js');
};

BootstrapLessGenerator.prototype.packageJSON = function packageJSON() {
  this.template('_package.json', 'package.json');
};

BootstrapLessGenerator.prototype.git = function git() {
  this.copy('gitignore', '.gitignore');
  this.copy('gitattributes', '.gitattributes');
};

BootstrapLessGenerator.prototype.bower = function bower() {
  this.copy('bowerrc', '.bowerrc');
  this.copy('_bower.json', 'bower.json');
};

BootstrapLessGenerator.prototype.jshint = function jshint() {
  this.copy('jshintrc', '.jshintrc');
};

BootstrapLessGenerator.prototype.editorConfig = function editorConfig() {
  this.copy('editorconfig', '.editorconfig');
};

BootstrapLessGenerator.prototype.h5bp = function h5bp() {
  this.copy('favicon.ico', 'app/favicon.ico');
  this.copy('404.html', 'app/404.html');
  this.copy('robots.txt', 'app/robots.txt');
  this.copy('htaccess', 'app/.htaccess');
};

BootstrapLessGenerator.prototype.mainStylesheet = function mainStylesheet() {
  var html = '@import "../bower_components/bootstrap/less/bootstrap.less";\n\n';

  if (this.glyphicons) {
    html = html + '@import "../bower_components/bootstrap-glyphicons/less/bootstrap-glyphicons.less";\n\n';
  }

  if (this.fontawesome) {
    html = html + '@import "../bower_components/font-awesome/less/font-awesome.less";\n@FontAwesomePath: "../fonts";\n\n';
  }

  html = html + '.browsehappy {\n  margin: 0.2em 0; \n  background: #ccc; \n  color: #000; \n  padding: 0.2em 0; \n}\n\n';
  html = html + '.jumbotron {\n  margin: 50px auto 0 auto;\n}';
  this.write('app/styles/main.less', html);
};

BootstrapLessGenerator.prototype.writeIndex = function writeIndex() {
  // prepare default content text
  var defaults = ['HTML5 Boilerplate', 'Twitter Bootstrap'];
  var contentText = [
    '    <div class="container">',
    '      <div class="jumbotron">',
    '        <h1>\'Allo, \'Allo!</h1>',
    '        <p>You now have</p>',
    '        <ul>'
  ];

  this.indexFile = this.appendScripts(this.indexFile, 'scripts/main.js', [
    'bower_components/jquery/jquery.js',
    'scripts/main.js',
    'scripts/hello.js'
  ]);


  if (this.jsBootstrap) {
    // wire Twitter Bootstrap plugins
    this.indexFile = this.appendScripts(this.indexFile, 'scripts/vendor/bootstrap.js', [
      'bower_components/bootstrap/js/affix.js',
      'bower_components/bootstrap/js/alert.js',
      'bower_components/bootstrap/js/dropdown.js',
      'bower_components/bootstrap/js/tooltip.js',
      'bower_components/bootstrap/js/modal.js',
      'bower_components/bootstrap/js/transition.js',
      'bower_components/bootstrap/js/button.js',
      'bower_components/bootstrap/js/popover.js',
      'bower_components/bootstrap/js/carousel.js',
      'bower_components/bootstrap/js/scrollspy.js',
      'bower_components/bootstrap/js/collapse.js',
      'bower_components/bootstrap/js/tab.js'
    ]);
  }

  if (this.glyphicons) {
    defaults.push('Bootstrap-Glyphicons <i class="glyphicon glyphicon-ok"></i>');
  }

  if (this.fontawesome) {
    defaults.push('Font Awesome <i class="icon-flag"></i>');
  }

  this.mainJsFile = 'console.log(\'\\\'Allo \\\'Allo!\');';
  this.mainCoffeeFile = 'console.log "\'Allo from CoffeeScript!"';

  // iterate over defaults and create content string
  defaults.forEach(function (el) {
    contentText.push('          <li>' + el  + '</li>');
  });

  contentText = contentText.concat([
    '        </ul>',
    '        <p>installed.</p>',
    '        <h3>Enjoy coding! - Yeoman</h3>',
    '      </div>',
    '    </div>',
    ''
  ]);

  // append the default content
  this.indexFile = this.indexFile.replace('<body>', '<body>\n' + contentText.join('\n'));
};

BootstrapLessGenerator.prototype.app = function app() {
  this.mkdir('app');
  this.mkdir('app/scripts');
  this.mkdir('app/styles');
  this.mkdir('app/images');
  this.write('app/index.html', this.indexFile);
  this.write('app/scripts/hello.coffee', this.mainCoffeeFile);
  this.write('app/scripts/main.js', this.mainJsFile);
};
